@@ -8,7 +8,7 @@ from pyqtgraph import QtCore, QtGui
 from pyqtgraph.dockarea import Dock, DockArea
 
 from imageanalysis.structures import Scan
-from imageanalysis.ui.data_view.utils import ImageTool
+from imageanalysis.ui.data_view.image_tool import ImageTool
 
 
 class GriddedDataWidget(DockArea):
@@ -18,15 +18,14 @@ class GriddedDataWidget(DockArea):
         super(GriddedDataWidget, self).__init__()
 
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
-        
+
         self.scan = scan
 
         # Child widgets
-        self.image_tool_3d = ImageTool()
-        self.image_tool_2d = ImageTool()
+        self.image_tool = ImageTool(parent=self)
         self.controller = GriddedDataController(
             parent=self,
-            image_tool=self.image_tool_3d,
+            image_tool=self.image_tool,
             scan=scan
         )
 
@@ -38,26 +37,16 @@ class GriddedDataWidget(DockArea):
             hideTitle=True,
             closable=False
         )
-        self.image_tool_3d_dock = Dock(
+        self.image_tool_dock = Dock(
             name="Controller",
             size=(1, 5),
-            widget=self.image_tool_3d,
+            widget=self.image_tool,
             hideTitle=True,
             closable=False
         )
-        self.image_tool_2d_dock = Dock(
-            name="Controller",
-            size=(1, 5),
-            widget=self.image_tool_2d,
-            hideTitle=True,
-            closable=False
-        )
-        # Sets max height for controller
         self.controller_dock.setMaximumHeight(200)
-
-        # Add docks to dock area
         self.addDock(self.controller_dock)
-        self.addDock(self.image_tool_3d_dock, "bottom", self.controller_dock)
+        self.addDock(self.image_tool_dock, "bottom", self.controller_dock)
 
 
 class GriddedDataController(QtGui.QWidget):
@@ -118,11 +107,12 @@ class GriddedDataController(QtGui.QWidget):
             ctrl.indexChanged.connect(self._setSliceIndex)
         self.dimensionOrderChanged.connect(self._setDimensionOrder)
 
-        # Set initial image
+        # Sets initial image
         self._setImage()
 
     def _setSliceIndex(self) -> None:
         """Updates index to match index of last dimension controller."""
+
         self.slice_index = self.layout.itemAt(2).widget().index
         self._setImage()
 
@@ -142,16 +132,19 @@ class GriddedDataController(QtGui.QWidget):
         self.layout.itemAt(1).widget()._setEnabled(False)
         self.layout.itemAt(2).widget()._setEnabled(True)
 
+        if self.image_tool.controller.plot_3d_roi_ctrl.roi is not None:
+            self.image_tool.controller.plot_3d_roi_ctrl.roi._center()
+        self.image_tool.plot_3d.autoRange()
+
     def _setImage(self) -> None:
         """Loads image in connected image tool."""
+
         data = np.transpose(self.data, self.dim_order)
         image = data[:, :, self.slice_index]
         x_label = ["H", "K", "L"][self.dim_order[0]]
         y_label = ["H", "K", "L"][self.dim_order[1]]
-        slice_label = ["H", "K", "L"][self.dim_order[2]]
         x_coords = self.coords[self.dim_order[0]]
         y_coords = self.coords[self.dim_order[1]]
-        slice_coord = self.coords[self.dim_order[2]][self.slice_index]
 
         self.image_tool._setImage(
             image=image,
@@ -159,13 +152,12 @@ class GriddedDataController(QtGui.QWidget):
             x_label=x_label,
             y_label=y_label,
             x_coords=x_coords,
-            y_coords=y_coords,
-            slice_label=slice_label,
-            slice_coord=slice_coord
+            y_coords=y_coords
         )
 
     def dragEnterEvent(self, e) -> None:
         """For dragging a dimension controller."""
+
         e.accept()
 
     def dropEvent(self, e) -> None:
@@ -188,6 +180,7 @@ class GriddedDataController(QtGui.QWidget):
 
         e.accept()
         self.dimensionOrderChanged.emit()
+        self.dimensionOrderChanged.emit()
 
 
 class GriddedDimensionController(QtGui.QGroupBox):
